@@ -1,18 +1,6 @@
 """
-  Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 import hashlib
 from copy import copy
@@ -219,7 +207,8 @@ class Conditions(object):
         self.Equals = {}
         self.Parameters = {}
         try:
-            self.Equals = self._get_condition_equals(cfn.search_deep_keys(cfnlint.helpers.FUNCTION_EQUALS))
+            self.Equals = self._get_condition_equals(
+                cfn.search_deep_keys(cfnlint.helpers.FUNCTION_EQUALS))
             for condition_name in cfn.template.get('Conditions', {}):
                 self.Conditions[condition_name] = Condition(cfn.template, condition_name)
             # Configure parametrs Allowed Values if they have them
@@ -228,7 +217,9 @@ class Conditions(object):
                 if isinstance(parameter_values.get('AllowedValues'), list):
                     # Any parameter in a condition could be used but would have to be done by
                     # Ref so build a ref to match for getting an equivalent hash
-                    self.Parameters[get_hash({'Ref': parameter_name})] = parameter_values.get('AllowedValues')
+                    self.Parameters[
+                        get_hash({'Ref': parameter_name})
+                    ] = parameter_values.get('AllowedValues')
         except Exception as err:  # pylint: disable=W0703
             LOGGER.debug('While processing conditions got error: %s', err)
 
@@ -386,7 +377,8 @@ class Conditions(object):
             # fail safe to not create a lot of unrelated scenarios. Just test if they are true/false
             # At this point this value is completely arbitrary and not configurable
             if len(conditions) > 4:
-                LOGGER.info('Found %s conditions.  Limiting results to protect against heavy cpu time', len(conditions))
+                LOGGER.info(
+                    'Found %s conditions.  Limiting results to protect against heavy cpu time', len(conditions))
                 true_results = []
                 false_results = []
                 for condition in conditions:
@@ -403,7 +395,8 @@ class Conditions(object):
         if matched_conditions:
             scenarios = []
             for con_hash, sets in matched_equals.items():
-                scenarios = multiply_equals(scenarios, con_hash, sets, self.Parameters.get(con_hash))
+                scenarios = multiply_equals(scenarios, con_hash, sets,
+                                            self.Parameters.get(con_hash))
 
         for scenario in scenarios:
             r_condition = {}
